@@ -44,27 +44,27 @@ use FP::Carp;
 # `identity_scalar`? :
 
 sub identity {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     $_[0]
 }
 
 sub inc {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     $_[0] + 1
 }
 
 sub dec {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     $_[0] - 1
 }
 
 sub square {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     $_[0] * $_[0]
 }
 
 sub average {
-    @_ == 2 or fp_croak_nargs 2;
+    @_ == 2 or fp_croak_arity 2;
     ($_[0] + $_[1]) / 2
 }
 
@@ -97,7 +97,7 @@ sub minmax {
 # is there any better idea than ucfirst to distinguish from the
 # builtin? `fchomp` ?
 sub Chomp {
-    @_ == 1 or fp_croak_nargs 1;
+    @_ == 1 or fp_croak_arity 1;
     my ($str) = @_;
     chomp $str;
     $str
